# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/lib/petlib/ecpt_group.proto
"""Generated protocol buffer code."""
# third party
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="proto/lib/petlib/ecpt_group.proto",
    package="syft.lib.petlib",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n!proto/lib/petlib/ecpt_group.proto\x12\x0fsyft.lib.petlib"\x1e\n\tEcPtGroup\x12\x11\n\tgroup_nid\x18\x01 \x01(\x04\x62\x06proto3',
)


_ECPTGROUP = _descriptor.Descriptor(
    name="EcPtGroup",
    full_name="syft.lib.petlib.EcPtGroup",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="group_nid",
            full_name="syft.lib.petlib.EcPtGroup.group_nid",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=54,
    serialized_end=84,
)

DESCRIPTOR.message_types_by_name["EcPtGroup"] = _ECPTGROUP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EcPtGroup = _reflection.GeneratedProtocolMessageType(
    "EcPtGroup",
    (_message.Message,),
    {
        "DESCRIPTOR": _ECPTGROUP,
        "__module__": "proto.lib.petlib.ecpt_group_pb2"
        # @@protoc_insertion_point(class_scope:syft.lib.petlib.EcPtGroup)
    },
)
_sym_db.RegisterMessage(EcPtGroup)


# @@protoc_insertion_point(module_scope)



# third party
import torch as th

# syft absolute
import syft as sy
from syft import serialize
from syft.core.common import UID
from syft.core.store.storeable_object import StorableObject


def test_create_storable_obj() -> None:
    id = UID()
    data = UID()
    description = "This is a dummy test"
    tags = ["dummy", "test"]
    StorableObject(id=id, data=data, description=description, tags=tags)


def test_serde_storable_obj() -> None:
    id = UID()
    data = th.Tensor([1, 2, 3, 4])
    description = "This is a dummy test"
    tags = ["dummy", "test"]
    obj = StorableObject(id=id, data=data, description=description, tags=tags)

    blob = sy.serialize(obj=obj)

    sy.deserialize(blob=blob)


def test_serde_storable_obj_2() -> None:
    id = UID()
    data = th.Tensor([1, 2, 3, 4])
    description = "This is a dummy test"
    tags = ["dummy", "test"]
    obj = StorableObject(id=id, data=data, description=description, tags=tags)
    blob = serialize(obj)
    ds_obj = sy.deserialize(blob=blob)
    assert obj.id == ds_obj.id
    assert (obj.data == ds_obj.data).all()
    assert obj.description == ds_obj.description
    assert obj.tags == ds_obj.tags


# def test_serde_storable_obj_with_wrapped_class() -> None:
#     """Ensure that storable object serialization works wrapping non-syft classes (like np.ndarray)"""
#
#     id = UID()
#     data = np.array([1, 2, 3, 4])
#     description = "This is a dummy test"
#     tags = ["dummy", "test"]
#     obj = StorableObject(id=id, data=data, description=description, tags=tags)
#
#     blob = sy.serialize(obj=obj)
#
#     sy.deserialize(blob=blob)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/core/common/common_object.proto
"""Generated protocol buffer code."""
# third party
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="proto/core/common/common_object.proto",
    package="syft.core.common",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n%proto/core/common/common_object.proto\x12\x10syft.core.common"x\n\x0c\x43ommonObject\x12)\n\nuid_object\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12=\n\x15object_with_id_object\x18\x02 \x01(\x0b\x32\x1e.syft.core.common.ObjectWithID"1\n\x0cObjectWithID\x12!\n\x02id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID"\x14\n\x03UID\x12\r\n\x05value\x18\x01 \x01(\x0c\x62\x06proto3',
)


_COMMONOBJECT = _descriptor.Descriptor(
    name="CommonObject",
    full_name="syft.core.common.CommonObject",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="uid_object",
            full_name="syft.core.common.CommonObject.uid_object",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="object_with_id_object",
            full_name="syft.core.common.CommonObject.object_with_id_object",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=59,
    serialized_end=179,
)


_OBJECTWITHID = _descriptor.Descriptor(
    name="ObjectWithID",
    full_name="syft.core.common.ObjectWithID",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="syft.core.common.ObjectWithID.id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=181,
    serialized_end=230,
)


_UID = _descriptor.Descriptor(
    name="UID",
    full_name="syft.core.common.UID",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="syft.core.common.UID.value",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=232,
    serialized_end=252,
)

_COMMONOBJECT.fields_by_name["uid_object"].message_type = _UID
_COMMONOBJECT.fields_by_name["object_with_id_object"].message_type = _OBJECTWITHID
_OBJECTWITHID.fields_by_name["id"].message_type = _UID
DESCRIPTOR.message_types_by_name["CommonObject"] = _COMMONOBJECT
DESCRIPTOR.message_types_by_name["ObjectWithID"] = _OBJECTWITHID
DESCRIPTOR.message_types_by_name["UID"] = _UID
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CommonObject = _reflection.GeneratedProtocolMessageType(
    "CommonObject",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMMONOBJECT,
        "__module__": "proto.core.common.common_object_pb2"
        # @@protoc_insertion_point(class_scope:syft.core.common.CommonObject)
    },
)
_sym_db.RegisterMessage(CommonObject)

ObjectWithID = _reflection.GeneratedProtocolMessageType(
    "ObjectWithID",
    (_message.Message,),
    {
        "DESCRIPTOR": _OBJECTWITHID,
        "__module__": "proto.core.common.common_object_pb2"
        # @@protoc_insertion_point(class_scope:syft.core.common.ObjectWithID)
    },
)
_sym_db.RegisterMessage(ObjectWithID)

UID = _reflection.GeneratedProtocolMessageType(
    "UID",
    (_message.Message,),
    {
        "DESCRIPTOR": _UID,
        "__module__": "proto.core.common.common_object_pb2"
        # @@protoc_insertion_point(class_scope:syft.core.common.UID)
    },
)
_sym_db.RegisterMessage(UID)


# @@protoc_insertion_point(module_scope)



# third party
import petlib as pl

# syft relative
from ...generate_wrapper import GenerateWrapper
from ...proto.lib.petlib.ecpt_group_pb2 import EcPtGroup as EcPtGroup_PB


def object2proto_group(obj: pl.ec.EcGroup) -> EcPtGroup_PB:
    proto = EcPtGroup_PB()
    proto.group_nid = obj.nid()
    return proto


def proto2object_group(proto: EcPtGroup_PB) -> pl.ec.EcGroup:
    ec_group = pl.ec.EcGroup(proto.group_nid)
    return ec_group


GenerateWrapper(
    wrapped_type=pl.ec.EcGroup,
    import_path="petlib.ec.EcGroup",
    protobuf_scheme=EcPtGroup_PB,
    type_object2proto=object2proto_group,
    type_proto2object=proto2object_group,
)



# stdlib

# third party
from sympc.session import Session

# syft relative
from ...generate_wrapper import GenerateWrapper
from ...proto.lib.sympc.session_pb2 import MPCSession as MPCSession_PB
from .session_util import protobuf_session_deserializer
from .session_util import protobuf_session_serializer


def object2proto(obj: object) -> MPCSession_PB:
    proto = protobuf_session_serializer(obj)
    return proto


def proto2object(proto: MPCSession_PB) -> Session:
    session = protobuf_session_deserializer(proto)
    return session


GenerateWrapper(
    wrapped_type=Session,
    import_path="sympc.session.Session",
    protobuf_scheme=MPCSession_PB,
    type_object2proto=object2proto,
    type_proto2object=proto2object,
)



"""The purpose of this application is to allow us to dev and test PySyft
functionality on an actual local network. This is NOT meant to be run in
production (that's the *actual* grid's job)."""


# stdlib
import binascii
import json
import pickle  # nosec

# third party
from flask import Flask
from flask import request

# syft absolute
from syft.core.common.message import ImmediateSyftMessageWithReply
from syft.core.common.message import ImmediateSyftMessageWithoutReply
from syft.core.node.domain.domain import Domain
from syft.logger import critical

app = Flask(__name__)


domain = Domain(name="ucsf")


@app.route("/")
def get_client() -> str:
    client_metadata = domain.get_metadata_for_client()
    return pickle.dumps(client_metadata).hex()


@app.route("/recv", methods=["POST"])
def recv() -> str:
    hex_msg = request.get_json()["data"]
    msg = pickle.loads(binascii.unhexlify(hex_msg))  # nosec # TODO make less insecure
    reply = None
    critical(str(msg))
    if isinstance(msg, ImmediateSyftMessageWithReply):
        reply = domain.recv_immediate_msg_with_reply(msg=msg)
        # QUESTION: is this expected to be a json string with the top level key data =>
        return json.dumps({"data": pickle.dumps(reply).hex()})
    elif isinstance(msg, ImmediateSyftMessageWithoutReply):
        domain.recv_immediate_msg_without_reply(msg=msg)
    else:
        domain.recv_eventual_msg_without_reply(msg=msg)

    return str(msg)


def run() -> None:
    app.run()


run()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/grid/messages/association_messages.proto
"""Generated protocol buffer code."""
# third party
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


# syft absolute
from syft.proto.core.common import (
    common_object_pb2 as proto_dot_core_dot_common_dot_common__object__pb2,
)
from syft.proto.core.io import address_pb2 as proto_dot_core_dot_io_dot_address__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name="proto/grid/messages/association_messages.proto",
    package="syft.grid.messages",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n.proto/grid/messages/association_messages.proto\x12\x12syft.grid.messages\x1a%proto/core/common/common_object.proto\x1a\x1bproto/core/io/address.proto"\xa8\x01\n\x1dSendAssociationRequestMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x95\x01\n\x1eSendAssociationRequestResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\xab\x01\n ReceiveAssociationRequestMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x98\x01\n!ReceiveAssociationRequestResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\xab\x01\n RespondAssociationRequestMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x98\x01\n!RespondAssociationRequestResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\xa7\x01\n\x1cGetAssociationRequestMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x94\x01\n\x1dGetAssociationRequestResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\xa8\x01\n\x1dGetAssociationRequestsMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x95\x01\n\x1eGetAssociationRequestsResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\xaa\x01\n\x1f\x44\x65leteAssociationRequestMessage\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12&\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x15.syft.core.io.Address\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\'\n\x08reply_to\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Address"\x97\x01\n DeleteAssociationRequestResponse\x12%\n\x06msg_id\x18\x01 \x01(\x0b\x32\x15.syft.core.common.UID\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12&\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x15.syft.core.io.Addressb\x06proto3',
    dependencies=[
        proto_dot_core_dot_common_dot_common__object__pb2.DESCRIPTOR,
        proto_dot_core_dot_io_dot_address__pb2.DESCRIPTOR,
    ],
)


_SENDASSOCIATIONREQUESTMESSAGE = _descriptor.Descriptor(
    name="SendAssociationRequestMessage",
    full_name="syft.grid.messages.SendAssociationRequestMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.SendAssociationRequestMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.SendAssociationRequestMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.SendAssociationRequestMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.SendAssociationRequestMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=139,
    serialized_end=307,
)


_SENDASSOCIATIONREQUESTRESPONSE = _descriptor.Descriptor(
    name="SendAssociationRequestResponse",
    full_name="syft.grid.messages.SendAssociationRequestResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.SendAssociationRequestResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.SendAssociationRequestResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.SendAssociationRequestResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.SendAssociationRequestResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=310,
    serialized_end=459,
)


_RECEIVEASSOCIATIONREQUESTMESSAGE = _descriptor.Descriptor(
    name="ReceiveAssociationRequestMessage",
    full_name="syft.grid.messages.ReceiveAssociationRequestMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.ReceiveAssociationRequestMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.ReceiveAssociationRequestMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.ReceiveAssociationRequestMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.ReceiveAssociationRequestMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=462,
    serialized_end=633,
)


_RECEIVEASSOCIATIONREQUESTRESPONSE = _descriptor.Descriptor(
    name="ReceiveAssociationRequestResponse",
    full_name="syft.grid.messages.ReceiveAssociationRequestResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.ReceiveAssociationRequestResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.ReceiveAssociationRequestResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.ReceiveAssociationRequestResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.ReceiveAssociationRequestResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=636,
    serialized_end=788,
)


_RESPONDASSOCIATIONREQUESTMESSAGE = _descriptor.Descriptor(
    name="RespondAssociationRequestMessage",
    full_name="syft.grid.messages.RespondAssociationRequestMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.RespondAssociationRequestMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.RespondAssociationRequestMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.RespondAssociationRequestMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.RespondAssociationRequestMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=791,
    serialized_end=962,
)


_RESPONDASSOCIATIONREQUESTRESPONSE = _descriptor.Descriptor(
    name="RespondAssociationRequestResponse",
    full_name="syft.grid.messages.RespondAssociationRequestResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.RespondAssociationRequestResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.RespondAssociationRequestResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.RespondAssociationRequestResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.RespondAssociationRequestResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=965,
    serialized_end=1117,
)


_GETASSOCIATIONREQUESTMESSAGE = _descriptor.Descriptor(
    name="GetAssociationRequestMessage",
    full_name="syft.grid.messages.GetAssociationRequestMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.GetAssociationRequestMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.GetAssociationRequestMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.GetAssociationRequestMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.GetAssociationRequestMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1120,
    serialized_end=1287,
)


_GETASSOCIATIONREQUESTRESPONSE = _descriptor.Descriptor(
    name="GetAssociationRequestResponse",
    full_name="syft.grid.messages.GetAssociationRequestResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.GetAssociationRequestResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.GetAssociationRequestResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.GetAssociationRequestResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.GetAssociationRequestResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1290,
    serialized_end=1438,
)


_GETASSOCIATIONREQUESTSMESSAGE = _descriptor.Descriptor(
    name="GetAssociationRequestsMessage",
    full_name="syft.grid.messages.GetAssociationRequestsMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.GetAssociationRequestsMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.GetAssociationRequestsMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.GetAssociationRequestsMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.GetAssociationRequestsMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1441,
    serialized_end=1609,
)


_GETASSOCIATIONREQUESTSRESPONSE = _descriptor.Descriptor(
    name="GetAssociationRequestsResponse",
    full_name="syft.grid.messages.GetAssociationRequestsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.GetAssociationRequestsResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.GetAssociationRequestsResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.GetAssociationRequestsResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.GetAssociationRequestsResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1612,
    serialized_end=1761,
)


_DELETEASSOCIATIONREQUESTMESSAGE = _descriptor.Descriptor(
    name="DeleteAssociationRequestMessage",
    full_name="syft.grid.messages.DeleteAssociationRequestMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.DeleteAssociationRequestMessage.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.DeleteAssociationRequestMessage.address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.DeleteAssociationRequestMessage.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reply_to",
            full_name="syft.grid.messages.DeleteAssociationRequestMessage.reply_to",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1764,
    serialized_end=1934,
)


_DELETEASSOCIATIONREQUESTRESPONSE = _descriptor.Descriptor(
    name="DeleteAssociationRequestResponse",
    full_name="syft.grid.messages.DeleteAssociationRequestResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="msg_id",
            full_name="syft.grid.messages.DeleteAssociationRequestResponse.msg_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status_code",
            full_name="syft.grid.messages.DeleteAssociationRequestResponse.status_code",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="content",
            full_name="syft.grid.messages.DeleteAssociationRequestResponse.content",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="address",
            full_name="syft.grid.messages.DeleteAssociationRequestResponse.address",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1937,
    serialized_end=2088,
)

_SENDASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_SENDASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_SENDASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_SENDASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_SENDASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_RECEIVEASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_RECEIVEASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_RECEIVEASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_RECEIVEASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_RECEIVEASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_RESPONDASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_RESPONDASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_RESPONDASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_RESPONDASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_RESPONDASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_GETASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_GETASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETASSOCIATIONREQUESTSMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_GETASSOCIATIONREQUESTSMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETASSOCIATIONREQUESTSMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_GETASSOCIATIONREQUESTSRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_GETASSOCIATIONREQUESTSRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_DELETEASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_DELETEASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_DELETEASSOCIATIONREQUESTMESSAGE.fields_by_name[
    "reply_to"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
_DELETEASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "msg_id"
].message_type = proto_dot_core_dot_common_dot_common__object__pb2._UID
_DELETEASSOCIATIONREQUESTRESPONSE.fields_by_name[
    "address"
].message_type = proto_dot_core_dot_io_dot_address__pb2._ADDRESS
DESCRIPTOR.message_types_by_name[
    "SendAssociationRequestMessage"
] = _SENDASSOCIATIONREQUESTMESSAGE
DESCRIPTOR.message_types_by_name[
    "SendAssociationRequestResponse"
] = _SENDASSOCIATIONREQUESTRESPONSE
DESCRIPTOR.message_types_by_name[
    "ReceiveAssociationRequestMessage"
] = _RECEIVEASSOCIATIONREQUESTMESSAGE
DESCRIPTOR.message_types_by_name[
    "ReceiveAssociationRequestResponse"
] = _RECEIVEASSOCIATIONREQUESTRESPONSE
DESCRIPTOR.message_types_by_name[
    "RespondAssociationRequestMessage"
] = _RESPONDASSOCIATIONREQUESTMESSAGE
DESCRIPTOR.message_types_by_name[
    "RespondAssociationRequestResponse"
] = _RESPONDASSOCIATIONREQUESTRESPONSE
DESCRIPTOR.message_types_by_name[
    "GetAssociationRequestMessage"
] = _GETASSOCIATIONREQUESTMESSAGE
DESCRIPTOR.message_types_by_name[
    "GetAssociationRequestResponse"
] = _GETASSOCIATIONREQUESTRESPONSE
DESCRIPTOR.message_types_by_name[
    "GetAssociationRequestsMessage"
] = _GETASSOCIATIONREQUESTSMESSAGE
DESCRIPTOR.message_types_by_name[
    "GetAssociationRequestsResponse"
] = _GETASSOCIATIONREQUESTSRESPONSE
DESCRIPTOR.message_types_by_name[
    "DeleteAssociationRequestMessage"
] = _DELETEASSOCIATIONREQUESTMESSAGE
DESCRIPTOR.message_types_by_name[
    "DeleteAssociationRequestResponse"
] = _DELETEASSOCIATIONREQUESTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendAssociationRequestMessage = _reflection.GeneratedProtocolMessageType(
    "SendAssociationRequestMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _SENDASSOCIATIONREQUESTMESSAGE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.SendAssociationRequestMessage)
    },
)
_sym_db.RegisterMessage(SendAssociationRequestMessage)

SendAssociationRequestResponse = _reflection.GeneratedProtocolMessageType(
    "SendAssociationRequestResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SENDASSOCIATIONREQUESTRESPONSE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.SendAssociationRequestResponse)
    },
)
_sym_db.RegisterMessage(SendAssociationRequestResponse)

ReceiveAssociationRequestMessage = _reflection.GeneratedProtocolMessageType(
    "ReceiveAssociationRequestMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _RECEIVEASSOCIATIONREQUESTMESSAGE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.ReceiveAssociationRequestMessage)
    },
)
_sym_db.RegisterMessage(ReceiveAssociationRequestMessage)

ReceiveAssociationRequestResponse = _reflection.GeneratedProtocolMessageType(
    "ReceiveAssociationRequestResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RECEIVEASSOCIATIONREQUESTRESPONSE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.ReceiveAssociationRequestResponse)
    },
)
_sym_db.RegisterMessage(ReceiveAssociationRequestResponse)

RespondAssociationRequestMessage = _reflection.GeneratedProtocolMessageType(
    "RespondAssociationRequestMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONDASSOCIATIONREQUESTMESSAGE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.RespondAssociationRequestMessage)
    },
)
_sym_db.RegisterMessage(RespondAssociationRequestMessage)

RespondAssociationRequestResponse = _reflection.GeneratedProtocolMessageType(
    "RespondAssociationRequestResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONDASSOCIATIONREQUESTRESPONSE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.RespondAssociationRequestResponse)
    },
)
_sym_db.RegisterMessage(RespondAssociationRequestResponse)

GetAssociationRequestMessage = _reflection.GeneratedProtocolMessageType(
    "GetAssociationRequestMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETASSOCIATIONREQUESTMESSAGE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.GetAssociationRequestMessage)
    },
)
_sym_db.RegisterMessage(GetAssociationRequestMessage)

GetAssociationRequestResponse = _reflection.GeneratedProtocolMessageType(
    "GetAssociationRequestResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETASSOCIATIONREQUESTRESPONSE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.GetAssociationRequestResponse)
    },
)
_sym_db.RegisterMessage(GetAssociationRequestResponse)

GetAssociationRequestsMessage = _reflection.GeneratedProtocolMessageType(
    "GetAssociationRequestsMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETASSOCIATIONREQUESTSMESSAGE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.GetAssociationRequestsMessage)
    },
)
_sym_db.RegisterMessage(GetAssociationRequestsMessage)

GetAssociationRequestsResponse = _reflection.GeneratedProtocolMessageType(
    "GetAssociationRequestsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETASSOCIATIONREQUESTSRESPONSE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.GetAssociationRequestsResponse)
    },
)
_sym_db.RegisterMessage(GetAssociationRequestsResponse)

DeleteAssociationRequestMessage = _reflection.GeneratedProtocolMessageType(
    "DeleteAssociationRequestMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEASSOCIATIONREQUESTMESSAGE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.DeleteAssociationRequestMessage)
    },
)
_sym_db.RegisterMessage(DeleteAssociationRequestMessage)

DeleteAssociationRequestResponse = _reflection.GeneratedProtocolMessageType(
    "DeleteAssociationRequestResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEASSOCIATIONREQUESTRESPONSE,
        "__module__": "proto.grid.messages.association_messages_pb2"
        # @@protoc_insertion_point(class_scope:syft.grid.messages.DeleteAssociationRequestResponse)
    },
)
_sym_db.RegisterMessage(DeleteAssociationRequestResponse)


# @@protoc_insertion_point(module_scope)



# stdlib
from os import path
import os.path
from typing import Dict
from typing import Union

# third party
from packaging import version
import pytest
import torch
import torchvision as tv

# syft absolute
import syft as sy
from syft.lib.torchvision.allowlist import allowlist

fileName = "imageTensor.pt"

TORCHVISION_VERSION = version.parse(tv.__version__)


@pytest.fixture(scope="function")
def tens() -> torch.Tensor:
    if path.isfile("imageTensor.pt"):
        return torch.load("imageTensor.pt")
    else:
        cwd = os.getcwd()
        path_file = cwd + "/tests/syft/lib/torchvision/" + fileName
        return torch.load(path_file)


def version_supported(support_dict: Union[str, Dict[str, str]]) -> bool:
    if isinstance(support_dict, str):
        return True
    else:
        if "min_version" not in support_dict.keys():
            return True
        return TORCHVISION_VERSION >= version.parse(support_dict["min_version"])


def test_allowlist(root_client: sy.VirtualMachineClient, tens: torch.Tensor) -> None:
    torchvision = root_client.torchvision
    torch = root_client.torch
    try:
        tx = torch.rand(4)
        tx = tx * 2
    except Exception as e:
        print(e)
    transforms = torchvision.transforms
    transforms.RandomAffine(2)
    for item in allowlist:
        arr = item.split(".")
        # print(item)
        if (
            arr[1] == "datasets"
            and len(arr) <= 3
            and isinstance(allowlist[item], dict)
            and "test_parameters" in allowlist[item].keys()
            and version_supported(support_dict=allowlist[item])
        ):
            print(item)
            try:
                exec(item + allowlist[item]["test_parameters"])
            except RuntimeError as e:
                assert (
                    "not found" in str(e)
                    or "not present in the root directory" in str(e)
                    or "does not exist" in str(e)
                )
            except FileNotFoundError as e:
                assert "No such file or directory" in str(
                    e
                ) or "cannot find the path" in str(e)
            except ModuleNotFoundError as e:
                assert "No module named" in str(e)
            except KeyError:
                pass
        elif (
            isinstance(allowlist[item], dict)
            and version_supported(support_dict=allowlist[item])
            and "test_parameters" in allowlist[item].keys()
        ):
            exec(item + allowlist[item]["test_parameters"])
